/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __GIMP_DISPLAY_SHELL_DND_H__
#define __GIMP_DISPLAY_SHELL_DND_H__


void   gimp_display_shell_drop_drawable (GtkWidget     *widget,
                                         GimpViewable  *viewable,
                                         gpointer       data);
void   gimp_display_shell_drop_vectors  (GtkWidget     *widget,
                                         GimpViewable  *viewable,
                                         gpointer       data);
void   gimp_display_shell_drop_svg      (GtkWidget     *widget,
                                         const guchar  *svg_data,
                                         gsize          svg_data_length,
                                         gpointer       data);
void   gimp_display_shell_drop_pattern  (GtkWidget     *widget,
                                         GimpViewable  *viewable,
                                         gpointer       data);
void   gimp_display_shell_drop_color    (GtkWidget     *widget,
                                         const GimpRGB *color,
                                         gpointer       data);
void   gimp_display_shell_drop_buffer   (GtkWidget     *widget,
                                         GimpViewable  *viewable,
                                         gpointer       data);
void   gimp_display_shell_drop_uri_list (GtkWidget     *widget,
                                         GList         *uri_list,
                                         gpointer       data);


#endif /* __GIMP_DISPLAY_SHELL_DND_H__ */
